import React, { useEffect, useState } from 'react';
import { Navigate, useLocation } from 'react-router-dom';
import { Spin } from 'antd';
import { useApi } from '../hooks/useApi';

interface PrivateRouteProps {
  children: React.ReactNode;
  requiredRoles?: string[]; // Теперь соответствует router.tsx
}

interface User {
  id: number;
  username: string;
  role: string;
}

const PrivateRoute: React.FC<PrivateRouteProps> = ({ children, requiredRoles }) => {
  const [isAuthenticated, setIsAuthenticated] = useState<boolean | null>(null);
  const [user, setUser] = useState<User | null>(null);
  const location = useLocation();
  const { execute: validateToken } = useApi<{ valid: boolean; user: User }>('/auth/validate', 'POST');

  useEffect(() => {
    let isMounted = true;

    const checkAuth = async () => {
      const token = localStorage.getItem('token');
      if (!token) {
        if (isMounted) setIsAuthenticated(false);
        return;
      }

      try {
        const response = await validateToken({});
        if (response?.valid) {
          if (isMounted) {
            setIsAuthenticated(true);
            setUser(response.user);
          }
        } else {
          if (isMounted) {
            setIsAuthenticated(false);
            localStorage.removeItem('token');
          }
        }
      } catch {
        if (isMounted) {
          setIsAuthenticated(false);
          localStorage.removeItem('token');
        }
      }
    };

    checkAuth();

    return () => {
      isMounted = false;
    };
  }, []);

  // Показываем спиннер во время проверки
  if (isAuthenticated === null) {
    return (
      <div style={{ display: 'flex', justifyContent: 'center', alignItems: 'center', height: '100vh' }}>
        <Spin size="large" tip="Проверка авторизации...">
          <div style={{ height: '1px' }} /> {/* Пустой div как вложенный контент */}
        </Spin>
      </div>
    );
  }
  

  // Если не авторизован, редиректим на логин
  if (!isAuthenticated) {
    return <Navigate to="/login" state={{ from: location }} replace />;
  }

  // Проверяем роль, если требуется
  if (requiredRoles && user && !requiredRoles.includes(user.role)) {
    return <Navigate to="/dashboard" replace />;
  }

  return <>{children}</>;
};

export default PrivateRoute;
