import React, { useState, useEffect } from 'react';
import { Table, Button, Modal, Form, Input, Select, Space, App as AntdApp } from 'antd';
import { useGet, usePost, usePut, useDelete } from '../../hooks/useApi';

interface Location {
  id: number;
  name: string;
}

interface Category {
  id: number;
  name: string;
  location_id: number;
  location: Location;
}

const CategoryManagement: React.FC = () => {
  const [isModalVisible, setIsModalVisible] = useState(false);
  const [editingCategory, setEditingCategory] = useState<Category | null>(null);
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const { message } = AntdApp.useApp();
  // Используем `useGet` для загрузки категорий и локаций
  const { data: categories, execute: fetchCategories } = useGet<Category[]>('/admin/categories');
  const { data: locations, execute: fetchLocations } = useGet<Location[]>('/admin/locations');

  // Используем `usePost`, `usePut` и `useDelete` для работы с категориями
  const { execute: createCategory } = usePost('/admin/categories');
  const { execute: updateCategory } = usePut(`/admin/categories/${editingCategory?.id}`);
  const { execute: deleteCategory } = useDelete(`/admin/categories`);

  // Загружаем данные при монтировании компонента
  useEffect(() => {
    fetchCategories();
    fetchLocations();
  }, []);

  // Отправка формы (создание или обновление категории)
  const handleSubmit = async (values: any) => {
    setLoading(true);
    try {
      if (editingCategory) {
        await updateCategory(values);
        message.success('Категория обновлена');
      } else {
        await createCategory(values);
        message.success('Категория создана');
      }
      setIsModalVisible(false);
      form.resetFields();
      setEditingCategory(null);
      fetchCategories(); // Обновляем список категорий
    } catch {
      message.error('Ошибка при сохранении категории');
    } finally {
      setLoading(false);
    }
  };

  // Открытие модального окна для редактирования категории
  const handleEdit = (category: Category) => {
    setEditingCategory(category);
    form.setFieldsValue({
      name: category.name,
      location_id: category.location_id
    });
    setIsModalVisible(true);
  };

  // Удаление категории
  const handleDelete = async (categoryId: number) => {
    try {
      await deleteCategory(categoryId);
      message.success('Категория удалена');
      fetchCategories(); // Обновляем список категорий
    } catch {
      message.error('Ошибка при удалении категории');
    }
  };

  // Определение столбцов таблицы
  const columns = [
    {
      title: 'Название',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: 'Локация',
      dataIndex: ['location', 'name'],
      key: 'location',
    },
    {
      title: 'Действия',
      key: 'actions',
      render: (_: any, record: Category) => (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)}>
            Редактировать
          </Button>
          <Button 
            type="link" 
            danger
            onClick={() => handleDelete(record.id)}
          >
            Удалить
          </Button>
        </Space>
      ),
    },
  ];

  return (
    <div>
      <div style={{ marginBottom: 16, display: 'flex', gap: 16 }}>
        <Button
          type="primary"
          onClick={() => {
            setEditingCategory(null);
            form.resetFields();
            setIsModalVisible(true);
          }}
        >
          Создать категорию
        </Button>
      </div>

      <Table
        columns={columns}
        dataSource={categories || []}
        rowKey="id"
        loading={!categories}
      />

      <Modal
        title={editingCategory ? 'Редактировать категорию' : 'Создать категорию'}
        open={isModalVisible}
        onOk={() => form.submit()}
        onCancel={() => {
          setIsModalVisible(false);
          setEditingCategory(null);
          form.resetFields();
        }}
        confirmLoading={loading}
      >
        <Form
          form={form}
          onFinish={handleSubmit}
          layout="vertical"
        >
          <Form.Item
            name="name"
            label="Название"
            rules={[{ required: true, message: 'Введите название категории' }]}
          >
            <Input />
          </Form.Item>

          <Form.Item
            name="location_id"
            label="Локация"
            rules={[{ required: true, message: 'Выберите локацию' }]}
          >
            <Select>
              {(locations || []).map(location => (
                <Select.Option key={location.id} value={location.id}>
                  {location.name}
                </Select.Option>
              ))}
            </Select>
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default CategoryManagement;
