import React, { useState, useEffect } from 'react';
import { Table, Button, Modal, Form, Input, InputNumber, Select, Space, App as AntdApp } from 'antd';
import { useGet, usePost, usePut, useDelete } from '../../hooks/useApi';

interface Item {
  id: number;
  name: string;
  code: string;
  quantity: number;
}

interface BoxItem {
  id: number;
  item_id: number;
  quantity: number;
  item: Item;
}

interface Box {
  id: number;
  name: string;
  items: BoxItem[];
}

interface BoxManagementProps {
  categoryId: number;
  items: Item[];
  onUpdate: () => void;
}

const BoxManagement: React.FC<BoxManagementProps> = ({ categoryId, items, onUpdate }) => {
  const [isModalVisible, setIsModalVisible] = useState(false);
  const [editingBox, setEditingBox] = useState<Box | null>(null);
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const { message } = AntdApp.useApp();
  // Используем `useGet` для загрузки коробок
  const { data: boxes, execute: fetchBoxes } = useGet<Box[]>(`/inventory/categories/${categoryId}/boxes`);

  // Используем `usePost`, `usePut`, `useDelete`
  const { execute: createBox } = usePost('/inventory/boxes');
  const { execute: updateBox } = usePut(`/inventory/boxes/${editingBox?.id}`);
  const { execute: deleteBox } = useDelete(`/inventory/boxes/${editingBox?.id}`);

  // Загружаем данные при монтировании компонента
  useEffect(() => {
    fetchBoxes();
  }, [categoryId]);

  // Отправка формы (создание или обновление коробки)
  const handleSubmit = async (values: any) => {
    setLoading(true);
    try {
      const boxData = {
        name: values.name,
        category_id: categoryId,
        items: values.items?.map((item: any) => ({
          item_id: item.item_id,
          quantity: item.quantity,
        })) || [],
      };

      if (editingBox) {
        await updateBox(boxData);
        message.success('Коробка обновлена');
      } else {
        await createBox(boxData);
        message.success('Коробка создана');
      }
      setIsModalVisible(false);
      form.resetFields();
      setEditingBox(null);
      fetchBoxes();
      onUpdate();
    } catch {
      message.error('Ошибка при сохранении коробки');
    } finally {
      setLoading(false);
    }
  };

  // Открытие модального окна для редактирования коробки
  const handleEdit = (box: Box) => {
    setEditingBox(box);
    form.setFieldsValue({
      name: box.name,
      items: box.items.map((item) => ({
        item_id: item.item_id,
        quantity: item.quantity,
      })),
    });
    setIsModalVisible(true);
  };

  // Удаление коробки
  const handleDelete = async (boxId: number) => {
    try {
      await deleteBox(boxId);
      message.success('Коробка удалена');
      fetchBoxes();
      onUpdate();
    } catch {
      message.error('Ошибка при удалении коробки');
    }
  };

  // Определение столбцов таблицы
  const columns = [
    {
      title: 'Название коробки',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: 'Содержимое',
      dataIndex: 'items',
      key: 'items',
      render: (items: BoxItem[]) => (
        <ul style={{ margin: 0, paddingLeft: 20 }}>
          {items.map((item) => (
            <li key={item.id}>
              {item.item.name} - {item.quantity} шт.
            </li>
          ))}
        </ul>
      ),
    },
    {
      title: 'Действия',
      key: 'actions',
      render: (_: any, record: Box) => (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)}>
            Редактировать
          </Button>
          <Button type="link" danger onClick={() => handleDelete(record.id)}>
            Удалить
          </Button>
        </Space>
      ),
    },
  ];

  return (
    <div>
      <Button
        type="primary"
        onClick={() => {
          setEditingBox(null);
          form.resetFields();
          setIsModalVisible(true);
        }}
        style={{ marginBottom: 16 }}
      >
        Создать коробку
      </Button>

      <Table
        columns={columns}
        dataSource={boxes || []}
        rowKey="id"
        loading={!boxes}
      />

      <Modal
        title={editingBox ? 'Редактировать коробку' : 'Создать коробку'}
        open={isModalVisible}
        onOk={() => form.submit()}
        onCancel={() => {
          setIsModalVisible(false);
          setEditingBox(null);
          form.resetFields();
        }}
        confirmLoading={loading}
        width={800}
      >
        <Form form={form} onFinish={handleSubmit} layout="vertical">
          <Form.Item
            name="name"
            label="Название коробки"
            rules={[{ required: true, message: 'Введите название коробки' }]}
          >
            <Input />
          </Form.Item>

          <Form.List name="items">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }) => (
                  <Space key={key} style={{ display: 'flex', marginBottom: 8 }} align="baseline">
                    <Form.Item
                      {...restField}
                      name={[name, 'item_id']}
                      rules={[{ required: true, message: 'Выберите товар' }]}
                    >
                      <Select style={{ width: 300 }}>
                        {items.map((item) => (
                          <Select.Option key={item.id} value={item.id}>
                            {item.name} ({item.code})
                          </Select.Option>
                        ))}
                      </Select>
                    </Form.Item>
                    <Form.Item
                      {...restField}
                      name={[name, 'quantity']}
                      rules={[{ required: true, message: 'Введите количество' }]}
                    >
                      <InputNumber min={1} placeholder="Количество" />
                    </Form.Item>
                    <Button type="link" danger onClick={() => remove(name)}>
                      Удалить
                    </Button>
                  </Space>
                ))}
                <Form.Item>
                  <Button type="dashed" onClick={() => add()} block>
                    Добавить товар
                  </Button>
                </Form.Item>
              </>
            )}
          </Form.List>
        </Form>
      </Modal>
    </div>
  );
};

export default BoxManagement;
