import React, { useState, useEffect } from 'react';
import { Table, Button, Modal, Form, Input, InputNumber, Space, Tabs, App as AntdApp } from 'antd';
import { useGet, usePost, usePut, useDelete } from '../../hooks/useApi';
import BoxManagement from './BoxManagement';

interface Item {
  id: number;
  name: string;
  code: string;
  description: string;
  quantity: number;
  category_id: number;
}

interface CategoryItemsProps {
  categoryId: number;
}

const CategoryItems: React.FC<CategoryItemsProps> = ({ categoryId }) => {
  const [isModalVisible, setIsModalVisible] = useState(false);
  const [editingItem, setEditingItem] = useState<Item | null>(null);
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const { message } = AntdApp.useApp();
  // Используем `useGet` для загрузки товаров
  const { data: items, execute: fetchItems } = useGet<Item[]>(`/inventory/categories/${categoryId}/items`);

  // Используем `usePost`, `usePut`, `useDelete` для управления товарами
  const { execute: createItem } = usePost('/inventory/items');
  const { execute: updateItem } = usePut(`/inventory/items/${editingItem?.id}`);
  const { execute: deleteItem } = useDelete(`/inventory/items/${editingItem?.id}`);

  // Загружаем данные при монтировании компонента
  useEffect(() => {
    fetchItems();
  }, [categoryId]);

  // Отправка формы (создание или обновление товара)
  const handleSubmit = async (values: any) => {
    setLoading(true);
    try {
      const itemData = {
        ...values,
        category_id: categoryId,
      };

      if (editingItem) {
        await updateItem(itemData);
        message.success('Товар обновлен');
      } else {
        await createItem(itemData);
        message.success('Товар создан');
      }

      setIsModalVisible(false);
      form.resetFields();
      setEditingItem(null);
      fetchItems();
    } catch {
      message.error('Ошибка при сохранении товара');
    } finally {
      setLoading(false);
    }
  };

  // Открытие модального окна для редактирования товара
  const handleEdit = (item: Item) => {
    setEditingItem(item);
    form.setFieldsValue({
      name: item.name,
      code: item.code,
      description: item.description,
      quantity: item.quantity,
    });
    setIsModalVisible(true);
  };

  // Удаление товара
  const handleDelete = async (itemId: number) => {
    try {
      await deleteItem(itemId);
      message.success('Товар удален');
      fetchItems();
    } catch {
      message.error('Ошибка при удалении товара');
    }
  };

  // Определение столбцов таблицы
  const columns = [
    {
      title: 'Код',
      dataIndex: 'code',
      key: 'code',
    },
    {
      title: 'Название',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: 'Описание',
      dataIndex: 'description',
      key: 'description',
    },
    {
      title: 'Количество',
      dataIndex: 'quantity',
      key: 'quantity',
    },
    {
      title: 'Действия',
      key: 'actions',
      render: (_: any, record: Item) => (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)}>
            Редактировать
          </Button>
          <Button type="link" danger onClick={() => handleDelete(record.id)}>
            Удалить
          </Button>
        </Space>
      ),
    },
  ];

  const tabItems = [
    {
      key: 'items',
      label: 'Товары',
      children: (
        <>
          <div style={{ marginBottom: 16 }}>
            <Button
              type="primary"
              onClick={() => {
                setEditingItem(null);
                form.resetFields();
                setIsModalVisible(true);
              }}
            >
              Добавить товар
            </Button>
          </div>
  
          <Table columns={columns} dataSource={items || []} rowKey="id" loading={!items} />
  
          <Modal
            title={editingItem ? 'Редактировать товар' : 'Добавить товар'}
            open={isModalVisible}
            onOk={() => form.submit()}
            onCancel={() => {
              setIsModalVisible(false);
              setEditingItem(null);
              form.resetFields();
            }}
            confirmLoading={loading}
          >
            <Form form={form} onFinish={handleSubmit} layout="vertical">
              <Form.Item
                name="code"
                label="Код"
                rules={[{ required: true, message: 'Введите код товара' }]}
              >
                <Input />
              </Form.Item>
  
              <Form.Item
                name="name"
                label="Название"
                rules={[{ required: true, message: 'Введите название товара' }]}
              >
                <Input />
              </Form.Item>
  
              <Form.Item name="description" label="Описание">
                <Input.TextArea />
              </Form.Item>
  
              <Form.Item
                name="quantity"
                label="Количество"
                rules={[{ required: true, message: 'Введите количество' }]}
              >
                <InputNumber min={0} style={{ width: '100%' }} />
              </Form.Item>
            </Form>
          </Modal>
        </>
      ),
    },
    {
      key: 'boxes',
      label: 'Коробки',
      children: <BoxManagement categoryId={categoryId} items={items || []} onUpdate={fetchItems} />,
    },
  ];
  
  return (
    <div>
      <Tabs defaultActiveKey="items" items={tabItems} />
    </div>
  );
};

export default CategoryItems;
